@@ -6,11 +6,13 @@ extends 'HTML::FormHandler::Field::IntRange';
 our $VERSION = '0.01';
 
 has '+range_start' => ( default => sub {
-       return (localtime)[5] + 1900 - 5;
+       my $year = (localtime)[5] + 1900 - 5;
+       return $year;
     }
 );
 has '+range_end' => ( default => sub {
-       return (localtime)[5] + 1900 + 10;
+       my $year = (localtime)[5] + 1900 + 10;
+       return $year;
    }
 );
 
