@@ -24,7 +24,7 @@ Use this module instead of C< use Moose::Role; >
 =cut
 
 Moose::Exporter->setup_import_methods(
-   with_caller => [ 'has_field', 'has_constraint' ],
+   with_caller => [ 'has_field', 'apply' ],
    also        => 'Moose::Role',
 );
 
@@ -44,9 +44,14 @@ sub has_field
 {
    my ( $class, $name, %options ) = @_;
 
-   $class->meta->add_to_field_list( $name, \%options );
+   $class->meta->add_to_field_list( { name => $name, %options } );
 }
 
+sub apply
+{
+   my ( $class, $arrayref ) = @_;
+   $class->meta->add_to_apply_list( @{$arrayref} );
+}
 
 =head1 AUTHOR
 
